@@ -1,4 +1,5 @@
 from .middleware import mk_jwt_middleware, mk_superadmin_middleware
-from .service import run_http_service, mk_http_service, run_many_services
+from .bottle_plugins import JWTPlugin, SuperadminAuthPlugin
+from .service import run_http_service, mk_http_service, run_many_services, run_many_bottle_services
 from .decorators import Decorator, DecoParam, Decora, replace_with_params, ch_func_to_all_pk, mk_flat, add_attrs
-from .openapi_utils import func_to_openapi_spec
+from .openapi_utils import func_to_openapi_spec
\ No newline at end of file
